%bcond_without reconf

Name: man-db
Version: 2.9.1
Release: 5
License: GPL-3.0-or-later
Summary: man command and related utilities
Url: http://www.nongnu.org/man-db

Source0: https://download.savannah.nongnu.org/releases/man-db/man-db-%{version}.tar.xz

Patch0: mandb_man.c.patch
Patch1: mandb-really-no-openat.patch
Patch2: mandb-no-o_search.patch
Patch3: man_db.conf.in.patch

BuildRequires: pkg-config
BuildRequires: libpipeline-devel 
BuildRequires: groff
BuildRequires: gdbm-devel
BuildRequires: libiconv-devel
BuildRequires: coreutils-gnu

%if %{with reconf}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: m4-gnu
BuildRequires: libtool
BuildRequires: gettext-tools
%endif

Requires: coreutils-gnu
Requires: groff
Requires: iconv-gnu
Requires: less
Requires: gzip

Recommends: bzip2
Recommends: xz
Recommends: lzip

%description
man-db is an implementation of the standard Unix documentation system accessed 
using the man command. It uses a Berkeley DB database in place of the traditional 
flat-text whatis databases.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build

%if %{with reconf}
autoreconf -fi
%else
%define _host powerpc-ibm-aix6
%endif

%configure \
  ac_cv_func_fstatat=no \
  ac_cv_func_openat=no \
  ac_cv_func_posix_fadvise=no \
  ac_cv_func_renameat=no \
  ac_cv_func_unlinkat=no \
  LDFLAGS="-Wl,-brtl -Wl,-blibpath:%{_libdir}/man-db:%{_libdir}:/QOpenSys/usr/lib" \
  --with-aix-soname=svr4 \
  --disable-cache-owner \
  --disable-setuid \
  --enable-shared \
  --disable-static \
  --with-pager=%{_bindir}/less \
  --with-nroff=%{_bindir}/nroff \
  --with-eqn=%{_bindir}/eqn \
  --with-neqn=%{_bindir}/neqn \
  --with-pic=%{_bindir}/pic \
  --with-refer=%{_bindir}/refer \
  --with-tbl=%{_bindir}/tbl \
  --with-gzip=%{_bindir}/gzip \
  --with-bzip2=%{_bindir}/bzip2 \
  --with-xz=%{_bindir}/xz \
  --with-lzma=%{_bindir}/lzma \
  --with-lzip=%{_bindir}/lzip \
  %if "%{_bindir}" != "%{_sbindir}"
  --sbindir=%{_bindir}
  %endif
  # end

%make_build

%install

%make_install
rm %{buildroot}%{_libdir}/man-db/libmandb.so
rm %{buildroot}%{_libdir}/man-db/libman.so

# create a symlink for previously shipped sbin/ files now in bin/
mkdir -p %{buildroot}%{_prefix}/sbin
ln -s %{_bindir}/accessdb %{buildroot}%{_prefix}/sbin/accessdb

%transfiletriggerin -- %{_mandir}
# update cache
    %{_bindir}/mandb -q >/dev/null 2>&1 || :
 
%transfiletriggerpostun -- %{_mandir}
# update cache
    %{_bindir}/mandb -q  >/dev/null 2>&1 || :

%files
%defattr(-, qsys, *none)
%doc NEWS
%doc README

%{_prefix}/sbin/accessdb

%{_bindir}/accessdb
%{_bindir}/manpath
%{_bindir}/mandb
%{_bindir}/man
%{_bindir}/apropos
%{_bindir}/whatis
%{_bindir}/lexgrog
%{_bindir}/catman
%{_bindir}/man-recode

%{_mandir}/man5/manpath.5*

%{_mandir}/man8/accessdb.8*
%{_mandir}/man8/mandb.8*
%{_mandir}/man8/catman.8*

%{_mandir}/man1/lexgrog.1*
%{_mandir}/man1/zsoelim.1*
%{_mandir}/man1/man.1*
%{_mandir}/man1/manconv.1*
%{_mandir}/man1/manpath.1*
%{_mandir}/man1/apropos.1*
%{_mandir}/man1/whatis.1*
%{_mandir}/man1/man-recode.1*

%{_docdir}/man-db/man-db-manual.txt
%{_docdir}/man-db/man-db-manual.ps

%{_libdir}/man-db/libmandb-%{version}.so
%{_libdir}/man-db/libman-%{version}.so

%config(noreplace) %{_sysconfdir}/man_db.conf

%{_libdir}exec/man-db/globbing
%{_libdir}exec/man-db/zsoelim
%{_libdir}exec/man-db/manconv


%changelog
* Mon Dec 20 2021 Mark Irish <mirish@ibm.com> - 2.9.1
- Move accessdb binary from .../sbin/ to .../bin/
- Create accessdb symlink from old .../sbin location to .../bin

* Wed Nov 18 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 2.9.1
- Use brp-rm-libtool-files

* Fri Jul 17 2020 Eric Simpson <esimpson@ca.ibm.com> - 2.9.1
- Add %transfiletriggerin and %transfiletriggerpostun to update cache

* Mon Jul 6 2020 Eric Simpson <esimpson@ca.ibm.com> - 2.9.1
- Update man_db.conf to use IBM i paths and specify %config(noreplace)

* Mon Jul 6 2020 Eric Simpson <esimpson@ca.ibm.com> - 2.9.1
- Add requires for groff, iconv-gnu, less, gzip
- Add recommends for bzip2, lzip, xz
- Specify -with* parameters to specify paths to utilities

* Mon Jun 15 2020 Kevin Adler <kadler@us.ibm.com> - 2.9.1
- Build with GNU libiconv
- Use less as the default pager

* Wed May 27 2020 Kevin Adler <kadler@us.ibm.com> - 2.9.1
- Use generic paths for man pages to allow for compression

* Thu May 7 2020 Eric Simpson <esimpson@ca.ibm.com>
- update to 2.9.1

* Mon Apr 27 2020 Eric Simpson <esimpson@ca.ibm.com>
- initial build for IBM i

* Thu Dec 05 2019 Kevin Adler <kadler@us.ibm.com> - 2.7.6.1
- Port patch from findutils to fix broken calls to fstatat
